==> taffybar-4.0.3-90-x86_64.pkg.tar.zst: usr/share/haskell/register/taffybar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   taffybar
version:                4.0.3
visibility:             public
id:                     taffybar-4.0.3-CgvPOdTLiFgLyaHM5Y31Qj
key:                    taffybar-4.0.3-CgvPOdTLiFgLyaHM5Y31Qj
license:                BSD-3-Clause
maintainer:             IvanMalison@gmail.com
author:                 Ivan Malison
homepage:               http://github.com/taffybar/taffybar
synopsis:               A desktop bar similar to xmobar, but with more GUI
category:               System
abi:                    ec5f0869edea0569d098e83db6c27746
exposed:                True
exposed-modules:
    System.Taffybar System.Taffybar.Auth System.Taffybar.Context
    System.Taffybar.DBus System.Taffybar.DBus.Toggle
    System.Taffybar.Example System.Taffybar.Hooks
    System.Taffybar.Information.Battery System.Taffybar.Information.CPU
    System.Taffybar.Information.CPU2 System.Taffybar.Information.Chrome
    System.Taffybar.Information.Crypto
    System.Taffybar.Information.DiskIO
    System.Taffybar.Information.EWMHDesktopInfo
    System.Taffybar.Information.MPRIS2
    System.Taffybar.Information.Memory
    System.Taffybar.Information.Network
    System.Taffybar.Information.SafeX11
    System.Taffybar.Information.StreamInfo
    System.Taffybar.Information.X11DesktopInfo
    System.Taffybar.Information.XDG.Protocol
    System.Taffybar.LogFormatter System.Taffybar.SimpleConfig
    System.Taffybar.Support.PagerHints System.Taffybar.Util
    System.Taffybar.Widget System.Taffybar.Widget.Battery
    System.Taffybar.Widget.CPUMonitor
    System.Taffybar.Widget.CommandRunner System.Taffybar.Widget.Crypto
    System.Taffybar.Widget.DiskIOMonitor
    System.Taffybar.Widget.FSMonitor
    System.Taffybar.Widget.FreedesktopNotifications
    System.Taffybar.Widget.Generic.AutoSizeImage
    System.Taffybar.Widget.Generic.ChannelGraph
    System.Taffybar.Widget.Generic.ChannelWidget
    System.Taffybar.Widget.Generic.DynamicMenu
    System.Taffybar.Widget.Generic.Graph
    System.Taffybar.Widget.Generic.Icon
    System.Taffybar.Widget.Generic.PollingBar
    System.Taffybar.Widget.Generic.PollingGraph
    System.Taffybar.Widget.Generic.PollingLabel
    System.Taffybar.Widget.Generic.VerticalBar
    System.Taffybar.Widget.Layout System.Taffybar.Widget.MPRIS2
    System.Taffybar.Widget.NetworkGraph System.Taffybar.Widget.SNITray
    System.Taffybar.Widget.SimpleClock
    System.Taffybar.Widget.SimpleCommandButton
    System.Taffybar.Widget.Text.CPUMonitor
    System.Taffybar.Widget.Text.MemoryMonitor
    System.Taffybar.Widget.Text.NetworkMonitor
    System.Taffybar.Widget.Util System.Taffybar.Widget.Weather
    System.Taffybar.Widget.Windows System.Taffybar.Widget.Workspaces
    System.Taffybar.Widget.WttrIn System.Taffybar.Widget.XDGMenu.Menu
    System.Taffybar.Widget.XDGMenu.MenuWidget
    System.Taffybar.WindowIcon

hidden-modules:
    Paths_taffybar System.Taffybar.DBus.Client.MPRIS2
    System.Taffybar.DBus.Client.Params
    System.Taffybar.DBus.Client.UPower
    System.Taffybar.DBus.Client.UPowerDevice
    System.Taffybar.DBus.Client.Util

import-dirs:            /usr/lib/ghc-9.4.8/site-local/taffybar-4.0.3
library-dirs:           /usr/lib/ghc-9.4.8/site-local/taffybar-4.0.3
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/taffybar-4.0.3
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/taffybar
hs-libraries:           HStaffybar-4.0.3-CgvPOdTLiFgLyaHM5Y31Qj
extra-libraries:
    gtk-3 gdk-3 z pangocairo-1.0 cairo-gobject gdk_pixbuf-2.0 atk-1.0
    pango-1.0 cairo harfbuzz gio-2.0 gobject-2.0 glib-2.0

extra-libraries-static:
    gtk-3 gdk-3 z pangocairo-1.0 m Xrandr Xcursor Xcomposite Xdamage
    Xinerama cloudproviders cairo-gobject m dl gdk_pixbuf-2.0 m tiff
    jbig z m zstd lzma pthread jpeg atk-bridge-2.0 atspi Xtst Xi Xfixes
    atk-1.0 dbus-1 systemd xkbcommon wayland-cursor wayland-egl
    wayland-client m rt epoxy dl GL EGL pangoft2-1.0 m pango-1.0 m
    fribidi thai datrie Xft cairo m dl fontconfig m expat m Xext
    Xrender X11 pthread xcb-render xcb-shm xcb Xau Xdmcp pixman-1 m
    harfbuzz-gobject harfbuzz m freetype bz2 png16 m m brotlidec
    brotlicommon graphite2 gio-2.0 gobject-2.0 ffi gmodule-2.0 glib-2.0
    m pcre2-8 z mount blkid sysprof-capture-4

include-dirs:
    /usr/include/gtk-3.0 /usr/include/pango-1.0
    /usr/include/cloudproviders /usr/include/cairo
    /usr/include/gdk-pixbuf-2.0 /usr/include/at-spi2-atk/2.0
    /usr/include/at-spi-2.0 /usr/include/atk-1.0 /usr/include/dbus-1.0
    /usr/lib/dbus-1.0/include /usr/include/fribidi
    /usr/include/pixman-1 /usr/include/harfbuzz /usr/include/freetype2
    /usr/include/libpng16 /usr/include/gio-unix-2.0
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/libmount /usr/include/blkid /usr/include/sysprof-6

depends:
    HStringTemplate-0.8.8-A7UGCKUstED7sTruQe1fxh
    X11-1.10.3-HY7umS8ccX59RQt2R5Ezi2
    aeson-2.1.2.1-CJUEk8Q0QXZ63rfmeHQCzY
    ansi-terminal-1.0.2-6TxOAUbfOQrDbPnWIRhRhS base-4.17.2.1
    broadcast-chan-0.2.1.2-EL2bp18GDj1Y8ziKOtHVF bytestring-0.11.5.3
    conduit-1.3.6.1-8tCAQIrauyrIug3BXDjEe3 containers-0.6.7
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi
    dbus-1.3.1-IyKVomIdcbdFFmxWiSnim0
    dbus-hslogger-0.1.0.1-BSRgUxB4FI3Imjeq96KiP7 directory-1.3.7.1
    dyre-0.9.2-6xsWj8cnPnO43rkWvoQDdD
    either-5.0.2-9aUxBHI0zljKbdI0y2ogoN
    enclosed-exceptions-1.0.3-AcpkEmm9n2ZFP17xvESRKz filepath-1.4.2.2
    gi-cairo-connector-0.1.1-6822bpLq4zVEdvsj51532r
    gi-cairo-render-0.1.2-Haw5VxJsY991vIM8TAK3V9
    gi-gdk-3.0.26-6I4zcDBtwFrAVQnrrSUpqo
    gi-gdkpixbuf-2.0.32-FtQ7JtbJUv2EdZKOyawO5c
    gi-gdkx11-3.0.13-CkMKBpsecFTHCcJmx8zJZW
    gi-glib-2.0.29-8UvWjME2Vp1CTPg5O1zU4v
    gi-gtk-3.0.39-5UYxHJj6ByvIR5PuwZMHMq
    gi-gtk-hs-0.3.16-EOO7qFcR1RwEZJt0rq8jYD
    gi-pango-1.0.29-63ZTnYWOrNCDSp1r4xUhC3
    gtk-sni-tray-0.1.8.1-9Phd7eURnDo4OgGWODAc6S
    gtk-strut-0.1.3.2-HKBtHnrmZWjH8IrB0gwKFG
    haskell-gi-base-0.26.6-8Q7bG4vZp6hk1q5uA8ktg
    hslogger-1.3.1.2-IDN4EJFBwuCAw75kd2IcUf
    http-client-0.7.18-FHhdytn5xYS9XZS4tP326d
    http-client-tls-0.3.6.4-3ApY1szHwQu9Wowklcak10
    http-conduit-2.3.9.1-JgIDB6YHdsWE6bMDl6N6NG
    http-types-0.12.4-BDoys3Aesb9DkjEWopUdY6
    multimap-1.2.1-IfPJLlwBCWEIVO8zC2m8uz parsec-3.1.16.1
    process-1.6.18.0 rate-limit-1.4.3-BthbfOgtEPJEcM0huInRc0
    regex-compat-0.95.2.2-XQpODnagAHFJ9GlOSqau8
    safe-0.3.21-2cieDnF9VN1Br7WvgeXGD
    scotty-0.22-7HvhJo03U4p77hsMyEOL2S
    split-0.2.5-4oYyCdOwbo5I1Zv7xTuLK
    status-notifier-item-0.3.1.0-9fnpSnpW74QEw9b0mtZzbs stm-2.5.1.0
    template-haskell-2.19.0.0 text-2.0.2 time-1.12.2
    time-locale-compat-0.1.1.5-1zJhxgkP2bvGiOhYof1wNA
    time-units-1.0.0-256CNFELv6i5YiHpTvd1at transformers-0.5.6.2
    tuple-0.3.0.2-1H0fGsnFsIa6u8fDgYTWIq unix-2.7.3
    utf8-string-1.0.2-FnO1h94XkEn7naEuvLflUO
    xdg-basedir-0.2.2-GUgbFy73ZJ02w1NqlBIm8a
    xdg-desktop-entry-0.1.1.2-9yj0gbiDCnFKXhyI3RntIP
    xml-1.3.14-Lx2FeToC7XoDX0aDGC9dRG
    xml-helpers-1.0.0-3ETMafV7UcH4BpT6TqDnxm
    xmonad-0.18.0-FlsTe4fYONY5kc4EyxYt3I

haddock-interfaces:     /usr/share/doc/taffybar/html/taffybar.haddock
haddock-html:           /usr/share/doc/taffybar/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> taffybar-4.0.3-91-x86_64.pkg.tar.zst: usr/share/haskell/register/taffybar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   taffybar
version:                4.0.3
visibility:             public
id:                     taffybar-4.0.3-9zeKyxV63dr1llYm7A0Yl2
key:                    taffybar-4.0.3-9zeKyxV63dr1llYm7A0Yl2
license:                BSD-3-Clause
maintainer:             IvanMalison@gmail.com
author:                 Ivan Malison
homepage:               http://github.com/taffybar/taffybar
synopsis:               A desktop bar similar to xmobar, but with more GUI
category:               System
abi:                    fe49738db3e73d63ba65afce576d9990
exposed:                True
exposed-modules:
    System.Taffybar System.Taffybar.Auth System.Taffybar.Context
    System.Taffybar.DBus System.Taffybar.DBus.Toggle
    System.Taffybar.Example System.Taffybar.Hooks
    System.Taffybar.Information.Battery System.Taffybar.Information.CPU
    System.Taffybar.Information.CPU2 System.Taffybar.Information.Chrome
    System.Taffybar.Information.Crypto
    System.Taffybar.Information.DiskIO
    System.Taffybar.Information.EWMHDesktopInfo
    System.Taffybar.Information.MPRIS2
    System.Taffybar.Information.Memory
    System.Taffybar.Information.Network
    System.Taffybar.Information.SafeX11
    System.Taffybar.Information.StreamInfo
    System.Taffybar.Information.X11DesktopInfo
    System.Taffybar.Information.XDG.Protocol
    System.Taffybar.LogFormatter System.Taffybar.SimpleConfig
    System.Taffybar.Support.PagerHints System.Taffybar.Util
    System.Taffybar.Widget System.Taffybar.Widget.Battery
    System.Taffybar.Widget.CPUMonitor
    System.Taffybar.Widget.CommandRunner System.Taffybar.Widget.Crypto
    System.Taffybar.Widget.DiskIOMonitor
    System.Taffybar.Widget.FSMonitor
    System.Taffybar.Widget.FreedesktopNotifications
    System.Taffybar.Widget.Generic.AutoSizeImage
    System.Taffybar.Widget.Generic.ChannelGraph
    System.Taffybar.Widget.Generic.ChannelWidget
    System.Taffybar.Widget.Generic.DynamicMenu
    System.Taffybar.Widget.Generic.Graph
    System.Taffybar.Widget.Generic.Icon
    System.Taffybar.Widget.Generic.PollingBar
    System.Taffybar.Widget.Generic.PollingGraph
    System.Taffybar.Widget.Generic.PollingLabel
    System.Taffybar.Widget.Generic.VerticalBar
    System.Taffybar.Widget.Layout System.Taffybar.Widget.MPRIS2
    System.Taffybar.Widget.NetworkGraph System.Taffybar.Widget.SNITray
    System.Taffybar.Widget.SimpleClock
    System.Taffybar.Widget.SimpleCommandButton
    System.Taffybar.Widget.Text.CPUMonitor
    System.Taffybar.Widget.Text.MemoryMonitor
    System.Taffybar.Widget.Text.NetworkMonitor
    System.Taffybar.Widget.Util System.Taffybar.Widget.Weather
    System.Taffybar.Widget.Windows System.Taffybar.Widget.Workspaces
    System.Taffybar.Widget.WttrIn System.Taffybar.Widget.XDGMenu.Menu
    System.Taffybar.Widget.XDGMenu.MenuWidget
    System.Taffybar.WindowIcon

hidden-modules:
    Paths_taffybar System.Taffybar.DBus.Client.MPRIS2
    System.Taffybar.DBus.Client.Params
    System.Taffybar.DBus.Client.UPower
    System.Taffybar.DBus.Client.UPowerDevice
    System.Taffybar.DBus.Client.Util

import-dirs:            /usr/lib/ghc-9.4.8/site-local/taffybar-4.0.3
library-dirs:           /usr/lib/ghc-9.4.8/site-local/taffybar-4.0.3
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/taffybar-4.0.3
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/taffybar
hs-libraries:           HStaffybar-4.0.3-9zeKyxV63dr1llYm7A0Yl2
extra-libraries:
    gtk-3 gdk-3 z pangocairo-1.0 cairo-gobject gdk_pixbuf-2.0 atk-1.0
    pango-1.0 cairo harfbuzz gio-2.0 gobject-2.0 glib-2.0

extra-libraries-static:
    gtk-3 gdk-3 z pangocairo-1.0 m Xrandr Xcursor Xcomposite Xdamage
    Xinerama cloudproviders cairo-gobject m dl gdk_pixbuf-2.0 m tiff
    jbig z m zstd lzma pthread jpeg atk-bridge-2.0 atspi Xtst Xi Xfixes
    atk-1.0 dbus-1 systemd xkbcommon wayland-cursor wayland-egl
    wayland-client m rt epoxy dl GL EGL pangoft2-1.0 m pango-1.0 m
    fribidi thai datrie Xft cairo m dl fontconfig m expat m Xext
    Xrender X11 pthread xcb-render xcb-shm xcb Xau Xdmcp pixman-1 m
    harfbuzz-gobject harfbuzz m freetype bz2 png16 m m brotlidec
    brotlicommon graphite2 gio-2.0 gobject-2.0 ffi gmodule-2.0 glib-2.0
    m pcre2-8 z mount blkid sysprof-capture-4

include-dirs:
    /usr/include/gtk-3.0 /usr/include/pango-1.0
    /usr/include/cloudproviders /usr/include/cairo
    /usr/include/gdk-pixbuf-2.0 /usr/include/at-spi2-atk/2.0
    /usr/include/at-spi-2.0 /usr/include/atk-1.0 /usr/include/dbus-1.0
    /usr/lib/dbus-1.0/include /usr/include/fribidi
    /usr/include/pixman-1 /usr/include/harfbuzz /usr/include/freetype2
    /usr/include/libpng16 /usr/include/gio-unix-2.0
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/libmount /usr/include/blkid /usr/include/sysprof-6

depends:
    HStringTemplate-0.8.8-JIWnma2RVe8AmL3kWdsJLj
    X11-1.10.3-HY7umS8ccX59RQt2R5Ezi2
    aeson-2.1.2.1-GOr0sGsn8HVJzt9KhewtB0
    ansi-terminal-1.0.2-D46JaHr1BfPBLAK7nuv4I base-4.17.2.1
    broadcast-chan-0.2.1.2-EL2bp18GDj1Y8ziKOtHVF bytestring-0.11.5.3
    conduit-1.3.6.1-GhV2KMoemFPB5FDryFR5X5 containers-0.6.7
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi
    dbus-1.3.1-HzIJLtUoAPa3Gnotv9SFuH
    dbus-hslogger-0.1.0.1-CGe87B57ivGCQi8PlQcAnu directory-1.3.7.1
    dyre-0.9.2-6xsWj8cnPnO43rkWvoQDdD
    either-5.0.2-6pxn4ZHF0O12s0wetU12Eh
    enclosed-exceptions-1.0.3-1T9jpW44i0h2e3ovo6d5ep filepath-1.4.2.2
    gi-cairo-connector-0.1.1-K1A2EbfMXCz1IJqS8qZZcw
    gi-cairo-render-0.1.2-BkBngUhVgdyJikxMqmXsq6
    gi-gdk-3.0.26-DDmdrqADGW225yUXMLSFzo
    gi-gdkpixbuf-2.0.32-Jk9gLfPUVfLH13LPHr3zg
    gi-gdkx11-3.0.13-JhBm5nuMq86rd9cbY2myb
    gi-glib-2.0.29-3USlM9arC84FVPyc3WX0bn
    gi-gtk-3.0.39-CGB0YhDVE5CFII6Euj2Ypz
    gi-gtk-hs-0.3.16-6DMTyHnYT6OFZNvgmbAY61
    gi-pango-1.0.29-CzmDODin0xEJWbN6jol0Vg
    gtk-sni-tray-0.1.8.1-FmU5IYJzrFr9wc7bqW2PBz
    gtk-strut-0.1.3.2-6FPeZJVNUz0GeYMADudC5l
    haskell-gi-base-0.26.6-8Q7bG4vZp6hk1q5uA8ktg
    hslogger-1.3.1.2-CgDEthnG1ldCvUFV6hkiDU
    http-client-0.7.18-16GRXSx1Un6FZdK2reCcpV
    http-client-tls-0.3.6.4-Cju796GoKjr7Bhv1tci6Mi
    http-conduit-2.3.9.1-Fr7XCF5XmoT9187GL9zJM8
    http-types-0.12.4-8b2vqk4ytrNGMVbZZ8fq7J
    multimap-1.2.1-IfPJLlwBCWEIVO8zC2m8uz parsec-3.1.16.1
    process-1.6.18.0 rate-limit-1.4.3-BthbfOgtEPJEcM0huInRc0
    regex-compat-0.95.2.2-XQpODnagAHFJ9GlOSqau8
    safe-0.3.21-4RbCGR2deY91o6dlI4zODz
    scotty-0.22-AFp69Nn0vnBInTTq5FaAfN
    split-0.2.5-m008juveJFC906Vg2goUt
    status-notifier-item-0.3.1.0-E3hFON2hJITKnCYX1TfNN3 stm-2.5.1.0
    template-haskell-2.19.0.0 text-2.0.2 time-1.12.2
    time-locale-compat-0.1.1.5-1zJhxgkP2bvGiOhYof1wNA
    time-units-1.0.0-256CNFELv6i5YiHpTvd1at transformers-0.5.6.2
    tuple-0.3.0.2-9YXtAamJZAh2GGuuUzpEsE unix-2.7.3
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    xdg-basedir-0.2.2-GUgbFy73ZJ02w1NqlBIm8a
    xdg-desktop-entry-0.1.1.2-F00nxEkXI4LH1qHsyutZ8e
    xml-1.3.14-Lx2FeToC7XoDX0aDGC9dRG
    xml-helpers-1.0.0-3ETMafV7UcH4BpT6TqDnxm
    xmonad-0.18.0-18wv2joBu80GTsB8q0nWce

haddock-interfaces:     /usr/share/doc/taffybar/html/taffybar.haddock
haddock-html:           /usr/share/doc/taffybar/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
